@@ -3,4 +3,4 @@ utils::globalVariables(c("value", "sigma", "condition", "x", "y", "name", "profl
                   "iteration", "idx", "is.zero", "index", "converged", "iterations",
                   ".runbgOutput", "terminal", "parvalue", "dataErrorModel",
                   "Rate", "weighted.residual", "i",
-                  "whichIndex"))
+                  "whichIndex", "symmetryDetectiondMod", "ODESS"))
