@@ -404,9 +404,12 @@ lbind <- function(mylist) {
   outlong <- do.call(rbind, lapply(1:length(conditions), function(cond) {
     
     myout <- mylist[[cond]]
-    myoutlong <- cbind(myout, condition = numconditions[cond])
+    if (nrow(myout) > 0)
+      myout[["condition"]] <- numconditions[cond]
+    else
+      myout[["condition"]] <- character(0)
     
-    return(myoutlong)
+    return(myout)
     
   }))
   
@@ -432,11 +435,9 @@ expand.grid.alt <- function(seq1, seq2) {
 #' @param args Additional arguments for the R CMD SHLIB call, e.g. \code{-leinspline}.
 #' @param verbose Print compiler output to R command line.
 #' @param cores Number of cores used for compilation when several files are compiled.
-#' @param recompile If .so-file with hash+output exists already, recompile and overwrite or don't?
 #' 
-#' @importFrom digest digest
 #' @export
-compile <- function(..., output = NULL, args = NULL, cores = 1, verbose = F, recompile = F) {
+compile <- function(..., output = NULL, args = NULL, cores = 1, verbose = F) {
   
   objects <- list(...)
   obj.names <- as.character(substitute(list(...)))[-1]
@@ -464,6 +465,9 @@ compile <- function(..., output = NULL, args = NULL, cores = 1, verbose = F, rec
   .so <- .Platform$dynlib.ext
   #print(files)
   
+  # Sanitize cores on windows
+  if (Sys.info()[['sysname']] == "Windows") cores <- 1
+  
   #return(files)
   if (is.null(output)) {
     compilation_out <- mclapply(1:length(files), function(i) {
@@ -472,25 +476,14 @@ compile <- function(..., output = NULL, args = NULL, cores = 1, verbose = F, rec
     }, mc.cores = cores, mc.silent = FALSE)
     for (r in roots) dyn.load(paste0(r, .so))
   } else {
-    # Append short hash of all .c-files which go into the compiled dll
-    output <- paste0(output, "_", substr(digest(list(roots)),1,8))
     for (i in 1:length(objects)) {
       eval(parse(text = paste0("modelname(", obj.names[i], ") <<- '", output, "'")))
     }
     for (r in roots) try(dyn.unload(paste0(r, .so)), silent = TRUE)
-    
-    if (file.exists(paste0(output, .so)) & !recompile) {
-      dyn.load(paste0(output, .so))
-      if (verbose) message("File already existing. Library was not overwritten.")
-      return(NULL)
-    }
-    
     try(dyn.unload(output), silent = TRUE)
     system(paste0(R.home(component = "bin"), "/R CMD SHLIB ", paste(files, collapse = " "), " -o ", output, .so, " ", args), intern = !verbose)
     dyn.load(paste0(output, .so))
   }
-  
-  
 }
 
 
@@ -541,8 +534,11 @@ loadDLL <- function(...) {
 
 sanitizeCores <- function(cores)  {
   
- if (Sys.info()[['sysname']] == "Windows") cores <- 1
- return(cores)
+  max.cores <- parallel::detectCores()
+  min(max.cores, cores)
+ #  
+ # if (Sys.info()[['sysname']] == "Windows") cores <- 1
+ # return(cores)
   
 }
 
@@ -572,6 +568,25 @@ sanitizePars <- function(pars = NULL, fixed = NULL) {
 }
 
 
+sanitizeData <- function(x, required = c("name", "time", "value"), imputed = c(sigma = NA, lloq = -Inf)) {
+  
+  all.names <- names(x)
+  
+  missing.required <- setdiff(required, all.names)
+  missing.imputed <- setdiff(names(imputed), all.names)
+  
+  if (length(missing.required) > 0)
+      stop("These mandatory columns are missing: ", paste(missing.required, collapse = ", "))
+  
+  if (length(missing.imputed) > 0) {
+    
+    for (n in missing.imputed) x[[n]] <- imputed[n]
+    
+  }
+  
+  list(data = x, columns = c(required, names(imputed)))
+  
+}
 
 
 #' Print list of dMod objects in .GlobalEnv
